aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/core_ext/hash.rb
diff options
context:
space:
mode:
authorDavid Heinemeier Hansson <david@loudthinking.com>2007-07-09 21:49:37 +0000
committerDavid Heinemeier Hansson <david@loudthinking.com>2007-07-09 21:49:37 +0000
commitcb2381696029ad839ecddad08afea061d07685fb (patch)
tree019bdde1381a1fd2e9423c494c13d76a048e4366 /activesupport/lib/active_support/core_ext/hash.rb
parent5b2be6293443a4c25aab7cf3e74fc84cb70e2199 (diff)
downloadrails-cb2381696029ad839ecddad08afea061d07685fb.tar.gz
rails-cb2381696029ad839ecddad08afea061d07685fb.tar.bz2
rails-cb2381696029ad839ecddad08afea061d07685fb.zip
Added Hash#except which is the inverse of Hash#slice -- return the hash except the keys that are specified [DHH]
git-svn-id: http://svn-commit.rubyonrails.org/rails/trunk@7172 5ecf4fe2-1ee6-0310-87b1-e25e094e27de
Diffstat (limited to 'activesupport/lib/active_support/core_ext/hash.rb')
-rw-r--r--activesupport/lib/active_support/core_ext/hash.rb3
1 files changed, 2 insertions, 1 deletions
diff --git a/activesupport/lib/active_support/core_ext/hash.rb b/activesupport/lib/active_support/core_ext/hash.rb
index 2a99468b4e..b805d2da62 100644
--- a/activesupport/lib/active_support/core_ext/hash.rb
+++ b/activesupport/lib/active_support/core_ext/hash.rb
@@ -1,4 +1,4 @@
%w(keys indifferent_access reverse_merge conversions diff slice).each do |ext|
require "#{File.dirname(__FILE__)}/hash/#{ext}"
end
@@ -9,4 +9,5 @@ class Hash #:nodoc:
include ActiveSupport::CoreExtensions::Hash::Conversions
include ActiveSupport::CoreExtensions::Hash::Diff
include ActiveSupport::CoreExtensions::Hash::Slice
+ include ActiveSupport::CoreExtensions::Hash::Except
end
@@ -1,4 +1,4 @@
-%w(keys indifferent_access reverse_merge conversions diff slice).each do |ext|
+%w(keys indifferent_access reverse_merge conversions diff slice except).each do |ext|
require "#{File.dirname(__FILE__)}/hash/#{ext}"
end